﻿using System;
using System.Collections.ObjectModel;
using System.Windows;
using System.Windows.Browser;
using System.Windows.Controls;
using System.Windows.Media;
using SilverlightApplication.GetDataService;
using ThinkGeo.MapSuite.SilverlightCore;
using ThinkGeo.MapSuite.SilverlightEdition;

namespace SilverlightApplication {

    [ScriptableTypeAttribute]
    public partial class MainPage : UserControl {
        private PointShape currentPoint;

        public MainPage() {
            InitializeComponent();
            UpdateSize();

            this.Loaded += new RoutedEventHandler(MainPage_Loaded);
            Map1.Click += new EventHandler<MapClickEventArgs>(Map1_Click);
        }

        [ScriptableMemberAttribute]
        public void UpdateSize() {
            Map1.Width = (double)HtmlPage.Document.Body.GetProperty("scrollWidth");
            Map1.Height = (double)HtmlPage.Document.Body.GetProperty("scrollHeight") - 135;
        }

        void Map1_Click(object sender, MapClickEventArgs e) {
            currentPoint = e.WorldPointShape;
            GetGeoDataServiceClient client = new GetGeoDataServiceClient();
            client.GetDataCompleted += new EventHandler<GetDataCompletedEventArgs>(client_GetDataCompleted);
            client.GetDataAsync(e.WorldPointShape.X, e.WorldPointShape.Y);
        }

        void client_GetDataCompleted(object sender, GetDataCompletedEventArgs e) {
            Collection<JsonFeature> jsonFeatures = (Collection<JsonFeature>)JsonConverter.ConvertStringToObjectUsingWcf(e.Result, typeof(Collection<JsonFeature>));
            InMemoryFeatureLayer inMemoryFeatureLayer = (InMemoryFeatureLayer)(((LayerOverlay)Map1.Overlays["MemoryOverlay"]).Layers[0]);
            foreach (JsonFeature jsonFeature in jsonFeatures) {
                Feature feature = new Feature(jsonFeature.Wkt, jsonFeature.Id);
                inMemoryFeatureLayer.FeatureSource.Open();
                inMemoryFeatureLayer.FeatureSource.BeginTransaction();
                inMemoryFeatureLayer.FeatureSource.AddFeature(feature);
                inMemoryFeatureLayer.FeatureSource.CommitTransaction();
                inMemoryFeatureLayer.FeatureSource.Close();
            }
            Map1.Refresh();
        }

        void MainPage_Loaded(object sender, RoutedEventArgs e) {
            HtmlPage.RegisterScriptableObject("MainPage", this);

            Map1.Background = new SolidColorBrush(Color.FromArgb(255, 156, 187, 216));
            Map1.MapUnit = GeographyUnit.DecimalDegree;

            WorldMapKitWmsSilverlightOverlay wmsOverlay = new WorldMapKitWmsSilverlightOverlay();
            Map1.Overlays.Add(wmsOverlay);

            ServerLayerOverlay serverLayerOverlay = new ServerLayerOverlay("NativeServerWithFleeBoolean", "SilverlightMapConnector1");
            serverLayerOverlay.IsStretchEffectDisabled = true;
            Map1.Overlays.Add(serverLayerOverlay);

            //Display the features returned from server-side, you could define the style you want.
            InMemoryFeatureLayer inMemoryLayer = new InMemoryFeatureLayer();
            inMemoryLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.FillSolidBrush.Color = GeoColor.FromArgb(100, GeoColor.StandardColors.RoyalBlue);
            inMemoryLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.OutlinePen.Color = GeoColor.StandardColors.Blue;
            inMemoryLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay overlay = new LayerOverlay();
            overlay.Layers.Add(inMemoryLayer);
            Map1.Overlays.Add("MemoryOverlay", overlay);

            Map1.CurrentExtent = new RectangleShape(-80.88515625, 73.659375, 143.06015625, -46.39921875);
        }
    }
}
